==> duiba-activity-service-api-0.0.1-20220330.014630-37-sources.jar: cn/com/duiba/cloud/duiba/activity/service/api/remoteservice/playways/remote/RemoteKeyValueApi.java <==
package cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.remote;

import cn.com.duiba.cloud.duiba.activity.service.api.utils.ExpireTime;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * key-value存储功能API
 * 本API中所有使用到的数据将会自动根据项目进行隔离，即不同项目之间无法互相访问数据，使用者无需关心不同项目key重复的问题
 * 请尽量避免在本数据结构中存储大文本，如果需要存储大文本，请使用{@link QueryTable}
 *
 */
public interface RemoteKeyValueApi {

    //默认失效时间 2099-01-01 00:00:00
     Date DEFAULT_EXPIRE_DATE = new Date(4070880000000L);

    /**
     * 获取{@code String}类型的值,
     *
     * @param key 键
     * @return 如果值存在且尚未过期，返回对应值；否则返回{@code null}
     */
    String get(Long activityId, String key);

    /**
     * 获取{@code Long}类型的值
     *
     *
     * @param key 键
     * @return 如果值存在且尚未过期，并且某个键对应的值是数字类型，返回对应值
     * 注: 如果对应的键不是数字类型，则返回{@code null}
     * 否则返回{@code null}
     */
    Long getLong(Long activityId, String key);

    /**
     * 批量获取{@code String}类型的值，如果某个键不存在，将使用{@code null}填充对应位置
     *
     * @param keys 键组成的列表
     * @return 由值组成的{@code List}，一定不会为{@code null}；如果值存在且尚未过期，目标位置为对应值；否则目标位置为{@code null}
     */
    List<String> multiGet(Long activityId, List<String> keys);

    /**
     * 批量获取{@code String}类型的值，如果某个键不存在，将使用{@code null}填充value值
     *
     * @param keys 键组成的列表
     * @return 如果value值存在且尚未过期，目标位置为对应值；否则目标位置为{@code null}
     */
    Map<String, String> multiGetNew(Long activityId, List<String> keys);

    /**
     * 批量获取{@code Long}类型的值，如果某个键不存在，将使用{@code null}填充value值
     *
     * @param keys 键组成的列表
     * @return 如果value值存在且尚未过期，目标位置为对应值；否则目标位置为{@code null}
     */
    Map<String, Long> multiGetLongNew(Long activityId, List<String> keys);

    /**
     * 批量获取{@code Long}类型的值，如果某个键不存在，将使用{@code null}填充对应位置
     *
     * @param keys 键组成的列表
     * @return 由值组成的 {@code List}，一定不会为{@code null}；如果值存在且尚未过期，目标位置为对应值；否则目标位置为{@code null}
     */
    List<Long> multiGetLong(Long activityId, List<String> keys);

    /**
     * 设置一个键值对，值为{@code String}类型，默认失效时间为 January 1, 2099, 00:00:00 GMT
     * 如果键不存在，则新增一条记录；如果键已经存在，则会修改值，但不会修改失效时间
     *
     * @param key   键
     * @param value 值
     */
    void set(Long activityId, String key, String value);

    /**
     * 设置一个键值对，值为{@code String}类型，并设置失效时间
     * 如果键不存在，则新增一条记录；如果键已经存在，则会修改值，并且设置失效时间
     * 等效于{@link ProjectApi#putKvStringData(String, String, java.util.Date)}
     *
     * @param key        键
     * @param value      值
     * @param expireTime 失效时间
     */
    void set(Long activityId, String key, String value, ExpireTime expireTime);

    /**
     * 设置一个键值对，值为{@code Long}类型，默认失效时间为 January 1, 2099, 00:00:00 GMT
     * 如果键不存在，则新增一条记录；如果键已经存在，则会修改值，但不会修改失效时间
     *
     * @param key   键
     * @param value 值
     */
    void set(Long activityId, String key, Long value);

    /**
     * 设置一个键值对，值为{@code Long}类型，并设置失效时间
     * 如果键不存在，则新增一条记录；如果键已经存在，则会修改值，并且设置失效时间
     *
     * @param key        键
     * @param value      值
     * @param expireTime 失效时间
     */
    void set(Long activityId, String key, Long value, ExpireTime expireTime);

    /**
     * 设置一个键值对，值为{@code String}类型，默认失效时间为 January 1, 2099, 00:00:00 GMT
     * 只有当键不存在时才会设置成功
     *
     * @param key   键
     * @param value 值
     * @return 设置记录成功时返回 {@code true};否则返回 {@code false}
     */
    boolean setIfAbsent(Long activityId, String key, String value);

    /**
     * 设置一个键值对，值为{@code String}类型，并设置失效时间
     * 只有当键不存在时才会设置成功
     *
     * @param key        键
     * @param value      值
     * @param expireTime 失效时间
     * @return 设置记录成功时返回 {@code true};否则返回 {@code false}
     */
    boolean setIfAbsent(Long activityId, String key, String value, ExpireTime expireTime);

    /**
     * 设置一个键值对，值为{@code Long}类型，默认失效时间为 January 1, 2099, 00:00:00 GMT
     * 只有当键不存在时才会设置成功
     *
     * @param key   键
     * @param value 值
     * @return 设置记录成功时返回 {@code true};否则返回 {@code false}
     */
    boolean setIfAbsent(Long activityId, String key, Long value);

    /**
     * 设置一个键值对，值为{@code Long}类型，并设置失效时间
     * 只有当键不存在时才会设置成功
     *
     * @param key        键
     * @param value      值
     * @param expireTime 失效时间
     * @return 设置记录成功时返回 {@code true};否则返回 {@code false}
     */
    boolean setIfAbsent(Long activityId, String key, Long value, ExpireTime expireTime);

    /**
     * 注意: 标记@Deprecated 的方法内部实现有性能问题，后续可能会删除，请使用 {@link RemoteKeyValueApi#increase(String key, long offset, Long limit)} 方法进行替换
     * 增长键对应的{@code Long}类型值，默认失效时间为 January 1, 2099, 00:00:00 GMT
     * 如果键不存在，则将创建一调记录再自增为1，并设置默认失效时间；否则在原值上进行自增，但不会修改失效时间
     * offset可以为负数，表示自减
     *
     * @param key    键
     * @param offset 增量
     * @return 增长完以后的值
     * @deprecated {@link #increase(String, long, Long)}
     */
    long increase(Long activityId, String key, long offset);

    /**
     * 增长键对应的{@code Long}类型值，并设置失效时间
     * 如果键不存在，则将创建一调记录再自增为1；否则在原值上进行自增，并修改失效时间
     * offset可以为负数，表示自减
     *
     * @param key    键
     * @param offset 增量
     * @return 增长完以后的值
     * @deprecated {@link #increase(String, long, Long, ExpireTime)}
     */
    long increase(Long activityId, String key, long offset, ExpireTime expireTime);

    /**
     * 增加key对应longValue值，并设置失效时间
     * 如果key不存在，则insert一条longValue为0的数据，再增加offset； 否则在原值上进行增加offset，并设置默认失效时间为 January 1, 2099, 00:00:00 GMT
     *
     * @param key    键
     * @param offset 增量:  offset可以为负数，表示减少
     * @param limit  阀值:  offset为正数时增加后的LongValue值不能大于limit， offset为负数时减少后的value值不能小于limit， 传NULL代表不限制
     * @return 成功/失败
     */
    @Deprecated
    boolean increase(Long activityId, String key, long offset, Long limit);

    /**
     * 增加key对应longValue值，并设置失效时间
     * 如果key不存在，则insert一条longValue为0的数据，再增加offset； 否则在原值上进行增加offset，并修改失效时间
     *
     * @param key        键
     * @param offset     增量:  offset可以为负数，表示减少
     * @param limit      阀值:  offset为正数时增加后的LongValue值不能大于limit， offset为负数时减少后的value值不能小于limit， 传NULL代表不限制
     * @param expireTime 失效时间, 传 NULL 为默认失效时间 January 1, 2099, 00:00:00 GMT
     * @return 成功/失败
     */
    boolean increase(Long activityId, String key, long offset, Long limit, ExpireTime expireTime);

    /**
     * 删除键对应的记录
     *
     * @param key 键
     * @return 如果键已存在且有效则返回 {@code true};否则返回 {@code false}
     */
    boolean delete(Long activityId, String key);

    /**
     * 批量删除键对应的记录
     *
     * @param keys 需要删除的键组成的list
     * @return 成功删除的有效记录数
     */
    int delete(Long activityId, List<String> keys);

    /**
     * 获取键对应的失效时间
     *
     * @param key 键
     * @return 如果键存在则返回其失效时间，如果不存在返回{@code null}
     */
    ExpireTime getExpire(Long activityId, String key);

    /**
     * 设置键对应的失效时间
     *
     * @param key        键
     * @param expireTime 失效时间
     * @return 如果键存在，返回 {@code true};否则返回 {@code false}
     */
    boolean expire(Long activityId, String key, ExpireTime expireTime);

    /**
     * 按项目唯独区分keykey
     * @param key
     * @return
     */
    default String genKey(Long activityId, String key) {
        return activityId + "_" + key;
    }


}

==> duiba-activity-service-api-0.0.1-20220401.100053-74-sources.jar: cn/com/duiba/cloud/duiba/activity/service/api/remoteservice/playways/remote/RemoteKeyValueApi.java <==
package cn.com.duiba.cloud.duiba.activity.service.api.remoteservice.playways.remote;

import cn.com.duiba.boot.exception.BizException;
import cn.com.duiba.cloud.duiba.activity.service.api.utils.ExpireTime;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * key-value存储功能API
 * 本API中所有使用到的数据将会自动根据项目进行隔离，即不同项目之间无法互相访问数据，使用者无需关心不同项目key重复的问题
 * 请尽量避免在本数据结构中存储大文本，如果需要存储大文本，请使用{@link QueryTable}
 *
 */
public interface RemoteKeyValueApi {

    //默认失效时间 2099-01-01 00:00:00
     Date DEFAULT_EXPIRE_DATE = new Date(4070880000000L);

    /**
     * 获取{@code String}类型的值,
     *
     * @param key 键
     * @return 如果值存在且尚未过期，返回对应值；否则返回{@code null}
     */
    String get(Long activityId, String key);

    /**
     * 获取{@code Long}类型的值
     *
     *
     * @param key 键
     * @return 如果值存在且尚未过期，并且某个键对应的值是数字类型，返回对应值
     * 注: 如果对应的键不是数字类型，则返回{@code null}
     * 否则返回{@code null}
     */
    Long getLong(Long activityId, String key);

    /**
     * 批量获取{@code String}类型的值，如果某个键不存在，将使用{@code null}填充对应位置
     *
     * @param keys 键组成的列表
     * @return 由值组成的{@code List}，一定不会为{@code null}；如果值存在且尚未过期，目标位置为对应值；否则目标位置为{@code null}
     */
    List<String> multiGet(Long activityId, List<String> keys);

    /**
     * 批量获取{@code String}类型的值，如果某个键不存在，将使用{@code null}填充value值
     *
     * @param keys 键组成的列表
     * @return 如果value值存在且尚未过期，目标位置为对应值；否则目标位置为{@code null}
     */
    Map<String, String> multiGetNew(Long activityId, List<String> keys);

    /**
     * 批量获取{@code Long}类型的值，如果某个键不存在，将使用{@code null}填充value值
     *
     * @param keys 键组成的列表
     * @return 如果value值存在且尚未过期，目标位置为对应值；否则目标位置为{@code null}
     */
    Map<String, Long> multiGetLongNew(Long activityId, List<String> keys);

    /**
     * 批量获取{@code Long}类型的值，如果某个键不存在，将使用{@code null}填充对应位置
     *
     * @param keys 键组成的列表
     * @return 由值组成的 {@code List}，一定不会为{@code null}；如果值存在且尚未过期，目标位置为对应值；否则目标位置为{@code null}
     */
    List<Long> multiGetLong(Long activityId, List<String> keys);

    /**
     * 设置一个键值对，值为{@code String}类型，默认失效时间为 January 1, 2099, 00:00:00 GMT
     * 如果键不存在，则新增一条记录；如果键已经存在，则会修改值，但不会修改失效时间
     *
     * @param key   键
     * @param value 值
     */
    void set(Long activityId, String key, String value) throws BizException;

    /**
     * 设置一个键值对，值为{@code String}类型，并设置失效时间
     * 如果键不存在，则新增一条记录；如果键已经存在，则会修改值，并且设置失效时间
     * 等效于{@link ProjectApi#putKvStringData(String, String, java.util.Date)}
     *
     * @param key        键
     * @param value      值
     * @param expireTime 失效时间
     */
    void set(Long activityId, String key, String value, ExpireTime expireTime) throws BizException;

    /**
     * 设置一个键值对，值为{@code Long}类型，默认失效时间为 January 1, 2099, 00:00:00 GMT
     * 如果键不存在，则新增一条记录；如果键已经存在，则会修改值，但不会修改失效时间
     *
     * @param key   键
     * @param value 值
     */
    void set(Long activityId, String key, Long value) throws BizException;

    /**
     * 设置一个键值对，值为{@code Long}类型，并设置失效时间
     * 如果键不存在，则新增一条记录；如果键已经存在，则会修改值，并且设置失效时间
     *
     * @param key        键
     * @param value      值
     * @param expireTime 失效时间
     */
    void set(Long activityId, String key, Long value, ExpireTime expireTime) throws BizException;

    /**
     * 设置一个键值对，值为{@code String}类型，默认失效时间为 January 1, 2099, 00:00:00 GMT
     * 只有当键不存在时才会设置成功
     *
     * @param key   键
     * @param value 值
     * @return 设置记录成功时返回 {@code true};否则返回 {@code false}
     */
    boolean setIfAbsent(Long activityId, String key, String value) throws BizException;

    /**
     * 设置一个键值对，值为{@code String}类型，并设置失效时间
     * 只有当键不存在时才会设置成功
     *
     * @param key        键
     * @param value      值
     * @param expireTime 失效时间
     * @return 设置记录成功时返回 {@code true};否则返回 {@code false}
     */
    boolean setIfAbsent(Long activityId, String key, String value, ExpireTime expireTime) throws BizException;

    /**
     * 设置一个键值对，值为{@code Long}类型，默认失效时间为 January 1, 2099, 00:00:00 GMT
     * 只有当键不存在时才会设置成功
     *
     * @param key   键
     * @param value 值
     * @return 设置记录成功时返回 {@code true};否则返回 {@code false}
     */
    boolean setIfAbsent(Long activityId, String key, Long value) throws BizException;

    /**
     * 设置一个键值对，值为{@code Long}类型，并设置失效时间
     * 只有当键不存在时才会设置成功
     *
     * @param key        键
     * @param value      值
     * @param expireTime 失效时间
     * @return 设置记录成功时返回 {@code true};否则返回 {@code false}
     */
    boolean setIfAbsent(Long activityId, String key, Long value, ExpireTime expireTime) throws BizException;

    /**
     * 注意: 标记@Deprecated 的方法内部实现有性能问题，后续可能会删除，请使用 {@link RemoteKeyValueApi#increase(String key, long offset, Long limit)} 方法进行替换
     * 增长键对应的{@code Long}类型值，默认失效时间为 January 1, 2099, 00:00:00 GMT
     * 如果键不存在，则将创建一调记录再自增为1，并设置默认失效时间；否则在原值上进行自增，但不会修改失效时间
     * offset可以为负数，表示自减
     *
     * @param key    键
     * @param offset 增量
     * @return 增长完以后的值
     * @deprecated {@link #increase(String, long, Long)}
     */
    long increase(Long activityId, String key, long offset) throws BizException;

    /**
     * 增长键对应的{@code Long}类型值，并设置失效时间
     * 如果键不存在，则将创建一调记录再自增为1；否则在原值上进行自增，并修改失效时间
     * offset可以为负数，表示自减
     *
     * @param key    键
     * @param offset 增量
     * @return 增长完以后的值
     * @deprecated {@link #increase(String, long, Long, ExpireTime)}
     */
    long increase(Long activityId, String key, long offset, ExpireTime expireTime) throws BizException;

    /**
     * 增加key对应longValue值，并设置失效时间
     * 如果key不存在，则insert一条longValue为0的数据，再增加offset； 否则在原值上进行增加offset，并设置默认失效时间为 January 1, 2099, 00:00:00 GMT
     *
     * @param key    键
     * @param offset 增量:  offset可以为负数，表示减少
     * @param limit  阀值:  offset为正数时增加后的LongValue值不能大于limit， offset为负数时减少后的value值不能小于limit， 传NULL代表不限制
     * @return 成功/失败
     */
    @Deprecated
    boolean increase(Long activityId, String key, long offset, Long limit) throws BizException;

    /**
     * 增加key对应longValue值，并设置失效时间
     * 如果key不存在，则insert一条longValue为0的数据，再增加offset； 否则在原值上进行增加offset，并修改失效时间
     *
     * @param key        键
     * @param offset     增量:  offset可以为负数，表示减少
     * @param limit      阀值:  offset为正数时增加后的LongValue值不能大于limit， offset为负数时减少后的value值不能小于limit， 传NULL代表不限制
     * @param expireTime 失效时间, 传 NULL 为默认失效时间 January 1, 2099, 00:00:00 GMT
     * @return 成功/失败
     */
    boolean increase(Long activityId, String key, long offset, Long limit, ExpireTime expireTime) throws BizException;

    /**
     * 删除键对应的记录
     *
     * @param key 键
     * @return 如果键已存在且有效则返回 {@code true};否则返回 {@code false}
     */
    boolean delete(Long activityId, String key);

    /**
     * 批量删除键对应的记录
     *
     * @param keys 需要删除的键组成的list
     * @return 成功删除的有效记录数
     */
    int delete(Long activityId, List<String> keys);

    /**
     * 获取键对应的失效时间
     *
     * @param key 键
     * @return 如果键存在则返回其失效时间，如果不存在返回{@code null}
     */
    ExpireTime getExpire(Long activityId, String key);

    /**
     * 设置键对应的失效时间
     *
     * @param key        键
     * @param expireTime 失效时间
     * @return 如果键存在，返回 {@code true};否则返回 {@code false}
     */
    boolean expire(Long activityId, String key, ExpireTime expireTime);

    /**
     * 按项目唯独区分keykey
     * @param key
     * @return
     */
    default String genKey(Long activityId, String key) {
        return activityId + "_" + key;
    }


}
